@@ -838,7 +838,7 @@ class IF(SystemIF, CommandIF, QueryIF, EventIF, Service_Application_Base_sample.
                 self.logger.debug("event_detail:{}".format(x))
                 self.logger.info("monitor_event:notify_event(subscribe_id:{})".format(subscribe_id))
             else:
-                self.logger.error("monitor_event:This_event({})_is_not_subscribed".format(event_type))
+                self.logger.info("monitor_event:This_event({})_is_not_subscribed".format(event_type))
 
     def monitor_event_from_sub_engine(self):
         while True:
